==> rtk-query-monitor-3.1.1.tgz: package/lib/esm/components/QueryPreviewApi.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import React, { PureComponent } from 'react';
import { QueryPreviewTabs } from '../types';
import { StyleUtilsContext } from '../styles/createStylingFromTheme';
import { TreeView } from './TreeView';
import { renderTabPanelId, renderTabPanelButtonId } from '../utils/a11y';
const rootProps = {
  'aria-labelledby': renderTabPanelButtonId(QueryPreviewTabs.apiConfig),
  id: renderTabPanelId(QueryPreviewTabs.apiConfig),
  role: 'tabpanel'
};
export class QueryPreviewApi extends PureComponent {
  constructor() {
    super(...arguments);
    _defineProperty(this, "shouldExpandApiStateNode", (keyPath, value, layer) => {
      const lastKey = keyPath[keyPath.length - 1];
      return layer <= 1 && lastKey !== 'config';
    });
  }
  render() {
    const {
      apiStats,
      isWideLayout,
      apiState
    } = this.props;
    if (!apiState) {
      return null;
    }
    const hasMutations = Object.keys(apiState.mutations).length > 0;
    const hasQueries = Object.keys(apiState.queries).length > 0;
    return /*#__PURE__*/React.createElement(StyleUtilsContext.Consumer, null, _ref => {
      let {
        styling
      } = _ref;
      return /*#__PURE__*/React.createElement("article", _extends({}, rootProps, styling('tabContent')), /*#__PURE__*/React.createElement("h2", null, apiState.config.reducerPath), /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "State"),
        data: apiState,
        shouldExpandNodeInitially: this.shouldExpandApiStateNode,
        isWideLayout: isWideLayout
      }), apiStats && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "Tally"),
        data: apiStats.tally,
        isWideLayout: isWideLayout
      }), hasQueries && /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "Queries Timings"),
        data: apiStats.timings.queries,
        isWideLayout: isWideLayout
      }), hasMutations && /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "Mutations Timings"),
        data: apiStats.timings.mutations,
        isWideLayout: isWideLayout
      })));
    });
  }
}

==> rtk-query-monitor-3.1.2.tgz: package/lib/esm/components/QueryPreviewApi.js <==
import _extends from "@babel/runtime/helpers/extends";
import React, { PureComponent } from 'react';
import { QueryPreviewTabs } from '../types';
import { StyleUtilsContext } from '../styles/createStylingFromTheme';
import { TreeView } from './TreeView';
import { renderTabPanelId, renderTabPanelButtonId } from '../utils/a11y';
const rootProps = {
  'aria-labelledby': renderTabPanelButtonId(QueryPreviewTabs.apiConfig),
  id: renderTabPanelId(QueryPreviewTabs.apiConfig),
  role: 'tabpanel'
};
export class QueryPreviewApi extends PureComponent {
  shouldExpandApiStateNode = (keyPath, value, layer) => {
    const lastKey = keyPath[keyPath.length - 1];
    return layer <= 1 && lastKey !== 'config';
  };
  render() {
    const {
      apiStats,
      isWideLayout,
      apiState
    } = this.props;
    if (!apiState) {
      return null;
    }
    const hasMutations = Object.keys(apiState.mutations).length > 0;
    const hasQueries = Object.keys(apiState.queries).length > 0;
    return /*#__PURE__*/React.createElement(StyleUtilsContext.Consumer, null, _ref => {
      let {
        styling
      } = _ref;
      return /*#__PURE__*/React.createElement("article", _extends({}, rootProps, styling('tabContent')), /*#__PURE__*/React.createElement("h2", null, apiState.config.reducerPath), /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "State"),
        data: apiState,
        shouldExpandNodeInitially: this.shouldExpandApiStateNode,
        isWideLayout: isWideLayout
      }), apiStats && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "Tally"),
        data: apiStats.tally,
        isWideLayout: isWideLayout
      }), hasQueries && /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "Queries Timings"),
        data: apiStats.timings.queries,
        isWideLayout: isWideLayout
      }), hasMutations && /*#__PURE__*/React.createElement(TreeView, {
        before: /*#__PURE__*/React.createElement("h3", null, "Mutations Timings"),
        data: apiStats.timings.mutations,
        isWideLayout: isWideLayout
      })));
    });
  }
}
